@@ -2,10 +2,10 @@ import logging
 import re
 import datetime
 import sqlalchemy as sa
-from babel.dates import format_datetime
+from babel.dates import format_datetime, format_date
 from formbar.renderer import FormRenderer, get_renderer
-from formbar.rules import Rule, Parser
 from formbar.helpers import get_local_datetime, get_utc_datetime
+from formbar.rules import Rule
 
 log = logging.getLogger(__name__)
 
@@ -398,7 +398,7 @@ class Form(object):
                 self._add_error(field.name, msg)
         elif dtype == 'email':
             # TODO: Really check the email. Ask the server mailsserver
-            # if the adress is known. (ti) <2014-08-04 16:31> 
+            # if the adress is known. (ti) <2014-08-04 16:31>
             if not value:
                 return None
             if not re.match(r"^[_a-z0-9-]+(\.[_a-z0-9-]+)*@[a-z0-9-]+(\.[a-z0-9-]+)*(\.[a-z]{2,4})$", value):
@@ -557,6 +557,9 @@ class Form(object):
                         value = get_local_datetime(value)
                         dateformat = "yyyy-MM-dd HH:mm:ss"
                         serialized = format_datetime(value, format=dateformat)
+                    elif ftype == "date":
+                        dateformat = "yyyy-MM-dd"
+                        serialized = format_date(value, format=dateformat)
                     else:
                         serialized = value
         except AttributeError:
@@ -589,16 +592,13 @@ class Form(object):
 
         if not submitted:
             unvalidated = self.loaded_data
-            # No need to convert the values here as the values are
-            # already pythonic when loaded from the item.
-            converted = unvalidated
         else:
             try:
                 self.submitted_data = submitted.mixed()
             except AttributeError:
                 self.submitted_data = submitted
             unvalidated = self.submitted_data
-            converted = self.deserialize(unvalidated)
+        converted = self.deserialize(unvalidated)
 
         # Validate the fields. Ignore fields which are disabled in
         # conditionals First get list of fields which are still in the
@@ -768,7 +768,7 @@ class Field(object):
             else:
                 return value
 
-    def _build_filter_expr(self, expr_str, item):
+    def _build_filter_rule(self, expr_str, item):
         t = expr_str.split(" ")
         for x in t:
             # % marks attributes of the current fields item in case of
@@ -789,7 +789,7 @@ class Field(object):
                     key = tokens[0].strip("$")
                     attribute = ".".join(tokens[1:])
                     # FIXME: This is a bad assumption that there is a
-                    # user within a request. (ti) <2014-07-09 11:18> 
+                    # user within a request. (ti) <2014-07-09 11:18>
                     if key == "user":
                         tmpitem = self._form._request.user
                 else:
@@ -803,12 +803,11 @@ class Field(object):
 
             if value is not None:
                 if isinstance(value, list):
-                    value = "[%s]" % ", ".join("'%s'" % unicode(v) for v in value)
+                    value = "[%s]" % ",".join("'%s'" % unicode(v) for v in value)
                     expr_str = expr_str.replace(x, value)
                 else:
                     expr_str = expr_str.replace(x, "'%s'" % str(value))
-        p = Parser()
-        return p.parse(expr_str)
+        return Rule(expr_str)
 
     def _load_options_from_db(self):
         # Get mapped clazz for the field
@@ -828,9 +827,8 @@ class Field(object):
         filtered_options = []
         for option in options:
             if self._config.renderer and self._config.renderer.filter:
-                expr = self._build_filter_expr(
+                rule = self._build_filter_rule(
                     self._config.renderer.filter, option)
-                rule = Rule(expr)
                 if rule.evaluate({}):
                     filtered_options.append((option, option.id, True))
                 else:
